@@ -40,7 +40,7 @@
 static CamelProviderConfEntry mh_conf_entries[] = {
 	CAMEL_PROVIDER_CONF_DEFAULT_PATH,
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "general", NULL, N_("Options") },
-	{ CAMEL_PROVIDER_CONF_CHECKBOX, "dotfolders", NULL,
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "use-dot-folders", NULL,
 	  N_("_Use the '.folders' folder summary file (exmh)"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_END }
@@ -54,6 +54,7 @@ static CamelProvider mh_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_IS_LOCAL,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_NEED_PATH_DIR | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	mh_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -72,6 +73,7 @@ static CamelProvider mbox_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_IS_LOCAL,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	mbox_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -80,7 +82,7 @@ static CamelProvider mbox_provider = {
 static CamelProviderConfEntry maildir_conf_entries[] = {
 	CAMEL_PROVIDER_CONF_DEFAULT_PATH,
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "general", NULL, N_("Options") },
-	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter", NULL,
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter-inbox", NULL,
 	  N_("_Apply filters to new messages in INBOX"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_END }
@@ -94,14 +96,16 @@ static CamelProvider maildir_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE | CAMEL_PROVIDER_IS_LOCAL,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_NEED_PATH_DIR | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	maildir_conf_entries,
+	NULL,
 	/* ... */
 };
 
 static CamelProviderConfEntry spool_conf_entries[] = {
 	CAMEL_PROVIDER_CONF_DEFAULT_PATH,
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "general", NULL, N_("Options") },
-	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter", NULL, N_("_Apply filters to new messages in INBOX"), "0" },
-	{ CAMEL_PROVIDER_CONF_CHECKBOX, "xstatus", NULL, N_("_Store status headers in Elm/Pine/Mutt format"), "0" },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter-inbox", NULL,
+	  N_("_Apply filters to new messages in INBOX"), "0" },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "use-xstatus-headers", NULL, N_("_Store status headers in Elm/Pine/Mutt format"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_END }
 };
@@ -114,6 +118,7 @@ static CamelProvider spool_file_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	spool_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -125,6 +130,7 @@ static CamelProvider spool_directory_provider = {
 	CAMEL_PROVIDER_IS_SOURCE | CAMEL_PROVIDER_IS_STORAGE,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_NEED_PATH_DIR | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
 	spool_conf_entries,
+	NULL,
 	/* ... */
 };
 
@@ -132,7 +138,8 @@ static CamelProvider spool_directory_provider = {
 
 /* build a canonical 'path' */
 static gchar *
-make_can_path (gchar *p, gchar *o)
+make_can_path (gchar *p,
+               gchar *o)
 {
 	gchar c, last, *start = o;
 
@@ -140,12 +147,12 @@ make_can_path (gchar *p, gchar *o)
 
 	last = 0;
 	while ((c = *p++)) {
-		if (c!='/'
-		    || (c=='/' && last != '/'))
+		if (c != '/'
+		    || (c == '/' && last != '/'))
 			*o++ = c;
 		last = c;
 	}
-	if (o>start && o[-1] == '/')
+	if (o > start && o[-1] == '/')
 		o[-1] = 0;
 	else
 		*o = 0;
@@ -180,7 +187,8 @@ local_url_hash (gconstpointer v)
 }
 
 static gint
-check_equal (gchar *s1, gchar *s2)
+check_equal (gchar *s1,
+             gchar *s2)
 {
 	if (s1 == NULL || *s1 == 0) {
 		if (s2 == NULL || *s2 == 0)
@@ -196,7 +204,8 @@ check_equal (gchar *s1, gchar *s2)
 }
 
 static gint
-local_url_equal (gconstpointer v, gconstpointer v2)
+local_url_equal (gconstpointer v,
+                 gconstpointer v2)
 {
 	const CamelURL *u1 = v, *u2 = v2;
 	gchar *p1, *p2;
