@@ -33,6 +33,7 @@
 #include <glib/gi18n-lib.h>
 
 #include "camel-mh-folder.h"
+#include "camel-mh-settings.h"
 #include "camel-mh-store.h"
 #include "camel-mh-summary.h"
 
@@ -57,13 +58,16 @@ folders_update (const gchar *root,
 {
 	gchar *tmp, *tmpnew, *line = NULL;
 	CamelStream *stream, *in = NULL, *out = NULL;
+	gchar *folder_newline;
 	gint flen = strlen (folder);
 
+	folder_newline = g_strdup_printf ("%s\n", folder);
+
 	tmpnew = g_alloca (strlen (root) + 16);
 	sprintf (tmpnew, "%s.folders~", root);
 
 	out = camel_stream_fs_new_with_name (
-		tmpnew, O_WRONLY|O_CREAT|O_TRUNC, 0666, NULL);
+		tmpnew, O_WRONLY | O_CREAT | O_TRUNC, 0666, NULL);
 	if (out == NULL)
 		goto fail;
 
@@ -75,8 +79,15 @@ folders_update (const gchar *root,
 		g_object_unref (stream);
 	}
 	if (in == NULL || stream == NULL) {
-		if (mode == UPDATE_ADD && camel_stream_printf (out, "%s\n", folder) == -1)
-			goto fail;
+		if (mode == UPDATE_ADD) {
+			gint ret;
+
+			ret = camel_stream_write_string (
+				out, folder_newline, cancellable, NULL);
+
+			if (ret == -1)
+				goto fail;
+		}
 		goto done;
 	}
 
@@ -92,7 +103,7 @@ folders_update (const gchar *root,
 			if (strncmp (line, folder, flen) == 0
 			    && (line[flen] == 0 || line[flen] == '/')) {
 				if (camel_stream_write (out, new, strlen (new), cancellable, NULL) == -1
-				    || camel_stream_write (out, line+flen, strlen (line)-flen, cancellable, NULL) == -1
+				    || camel_stream_write (out, line + flen, strlen (line) - flen, cancellable, NULL) == -1
 				    || camel_stream_write(out, "\n", 1, cancellable, NULL) == -1)
 					goto fail;
 				copy = FALSE;
@@ -102,8 +113,13 @@ folders_update (const gchar *root,
 			gint cmp = strcmp (line, folder);
 
 			if (cmp > 0) {
+				gint ret;
+
 				/* found insertion point */
-				if (camel_stream_printf(out, "%s\n", folder) == -1)
+				ret = camel_stream_write_string (
+					out, folder_newline, cancellable, NULL);
+
+				if (ret == -1)
 					goto fail;
 				mode = UPDATE_NONE;
 			} else if (tmp == NULL) {
@@ -115,16 +131,33 @@ folders_update (const gchar *root,
 			break;
 		}
 
-		if (copy && camel_stream_printf(out, "%s\n", line) == -1)
-			goto fail;
+		if (copy) {
+			gchar *string;
+			gint ret;
+
+			string = g_strdup_printf ("%s\n", line);
+			ret = camel_stream_write_string (
+				out, string, cancellable, NULL);
+			g_free (string);
+
+			if (ret == -1)
+				goto fail;
+		}
 
 		g_free (line);
 		line = NULL;
 	}
 
 	/* add to end? */
-	if (mode == UPDATE_ADD && camel_stream_printf(out, "%s\n", folder) == -1)
-		goto fail;
+	if (mode == UPDATE_ADD) {
+		gint ret;
+
+		ret = camel_stream_write_string (
+			out, folder_newline, cancellable, NULL);
+
+		if (ret == -1)
+			goto fail;
+	}
 
 	if (camel_stream_close (out, cancellable, NULL) == -1)
 		goto fail;
@@ -139,6 +172,8 @@ fail:
 		g_object_unref (in);
 	if (out)
 		g_object_unref (out);
+
+	g_free (folder_newline);
 }
 
 static void
@@ -147,8 +182,10 @@ fill_fi (CamelStore *store,
          guint32 flags,
          GCancellable *cancellable)
 {
+	CamelLocalStore *local_store;
 	CamelFolder *folder;
 
+	local_store = CAMEL_LOCAL_STORE (store);
 	folder = camel_object_bag_peek (store->folders, fi->full_name);
 
 	if (folder == NULL
@@ -156,12 +193,13 @@ fill_fi (CamelStore *store,
 		folder = camel_store_get_folder_sync (
 			store, fi->full_name, 0, cancellable, NULL);
 
-	if (folder) {
+	if (folder != NULL) {
 		if ((flags & CAMEL_STORE_FOLDER_INFO_FAST) == 0)
 			camel_folder_refresh_info_sync (folder, cancellable, NULL);
 		fi->unread = camel_folder_get_unread_message_count (folder);
 		fi->total = camel_folder_get_message_count (folder);
 		g_object_unref (folder);
+
 	} else {
 		gchar *path, *folderpath;
 		CamelFolderSummary *s;
@@ -170,14 +208,17 @@ fill_fi (CamelStore *store,
 		/* This should be fast enough not to have to test for INFO_FAST */
 
 		/* We could: if we have no folder, and FAST isn't specified, perform a full
-		   scan of all messages for their status flags.  But its probably not worth
-		   it as we need to read the top of every file, i.e. very very slow */
+		 * scan of all messages for their status flags.  But its probably not worth
+		 * it as we need to read the top of every file, i.e. very very slow */
 
-		root = camel_local_store_get_toplevel_dir ((CamelLocalStore *) store);
-		path = g_strdup_printf("%s/%s.ev-summary", root, fi->full_name);
-		folderpath = g_strdup_printf("%s/%s", root, fi->full_name);
-		s = (CamelFolderSummary *) camel_mh_summary_new (NULL, path, folderpath, NULL);
-		if (camel_folder_summary_header_load_from_db (s, store, fi->full_name, NULL) != -1) {
+		root = camel_local_store_get_toplevel_dir (local_store);
+		path = g_strdup_printf (
+			"%s/%s.ev-summary", root, fi->full_name);
+		folderpath = g_strdup_printf ("%s/%s", root, fi->full_name);
+		s = (CamelFolderSummary *) camel_mh_summary_new (
+			NULL, path, folderpath, NULL);
+		if (camel_folder_summary_header_load_from_db (
+			s, store, fi->full_name, NULL) != -1) {
 			fi->unread = s->unread_count;
 			fi->total = s->saved_count;
 		}
@@ -186,10 +227,12 @@ fill_fi (CamelStore *store,
 		g_free (path);
 	}
 
-	if (camel_local_store_is_main_store (CAMEL_LOCAL_STORE (store)) && fi->full_name
+	if (camel_local_store_is_main_store (local_store) && fi->full_name
 	    && (fi->flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_NORMAL)
-		fi->flags = (fi->flags & ~CAMEL_FOLDER_TYPE_MASK)
-			    | camel_local_store_get_folder_type_by_full_name (CAMEL_LOCAL_STORE (store), fi->full_name);
+		fi->flags =
+			(fi->flags & ~CAMEL_FOLDER_TYPE_MASK) |
+			camel_local_store_get_folder_type_by_full_name (
+				local_store, fi->full_name);
 }
 
 static CamelFolderInfo *
@@ -199,7 +242,8 @@ folder_info_new (CamelStore *store,
                  guint32 flags,
                  GCancellable *cancellable)
 {
-	/* FIXME: need to set fi->flags = CAMEL_FOLDER_NOSELECT (and possibly others) when appropriate */
+	/* FIXME Need to set fi->flags = CAMEL_FOLDER_NOSELECT
+	 *       (and possibly others) when appropriate. */
 	CamelFolderInfo *fi;
 	gchar *base;
 
@@ -208,7 +252,7 @@ folder_info_new (CamelStore *store,
 	/* Build the folder info structure. */
 	fi = camel_folder_info_new ();
 	fi->full_name = g_strdup (path);
-	fi->display_name = g_strdup (base?base+1:path);
+	fi->display_name = g_strdup (base ? base + 1 : path);
 	fill_fi (store, fi, flags, cancellable);
 
 	return fi;
@@ -284,13 +328,18 @@ recursive_scan (CamelStore *store,
 			if (*tmp == 0)
 				continue;
 
-			/* otherwise, treat at potential node, and recurse, a bit more expensive than needed, but tough! */
+			/* Otherwise, treat at potential node, and recurse,
+			 * a bit more expensive than needed, but tough! */
 			if (path[0]) {
 				tmp = g_strdup_printf("%s/%s", path, d->d_name);
-				recursive_scan (store, &fi->child, fi, visited, root, tmp, flags, cancellable);
+				recursive_scan (
+					store, &fi->child, fi, visited,
+					root, tmp, flags, cancellable);
 				g_free (tmp);
 			} else {
-				recursive_scan (store, &fi->child, fi, visited, root, d->d_name, flags, cancellable);
+				recursive_scan (
+					store, &fi->child, fi, visited,
+					root, d->d_name, flags, cancellable);
 			}
 		}
 
@@ -329,20 +378,25 @@ folders_scan (CamelStore *store,
 	visited = g_hash_table_new (g_str_hash, g_str_equal);
 	folders = g_ptr_array_new ();
 
-	while ( (len = camel_stream_buffer_gets ((CamelStreamBuffer *) in, line, sizeof (line), cancellable, NULL)) > 0) {
+	while ((len = camel_stream_buffer_gets (
+		(CamelStreamBuffer *) in, line,
+		sizeof (line), cancellable, NULL)) > 0) {
+
 		/* ignore blank lines */
 		if (len <= 1)
 			continue;
-		/* check for invalidly long lines, we abort evreything and fallback */
-		if (line[len-1] != '\n') {
+
+		/* Check for invalidly long lines,
+		 * we abort everything and fallback. */
+		if (line[len - 1] != '\n') {
 			gint i;
 
-			for (i=0;i<folders->len;i++)
+			for (i = 0; i < folders->len; i++)
 				camel_folder_info_free (folders->pdata[i]);
 			g_ptr_array_set_size (folders, 0);
 			break;
 		}
-		line[len-1] = 0;
+		line[len - 1] = 0;
 
 		/* check for \r ? */
 
@@ -357,7 +411,7 @@ folders_scan (CamelStore *store,
 			/* check is not sub-subdir if not recursive */
 			if ((flags & CAMEL_STORE_FOLDER_INFO_RECURSIVE) == 0
 			    && (tmp = strrchr (line, '/'))
-			    && tmp > line+toplen)
+			    && tmp > line + toplen)
 				continue;
 		}
 
@@ -369,7 +423,8 @@ folders_scan (CamelStore *store,
 
 		path = g_strdup_printf("%s/%s", root, line);
 		if (g_stat (path, &st) == 0 && S_ISDIR (st.st_mode)) {
-			fi = folder_info_new (store, root, line, flags, cancellable);
+			fi = folder_info_new (
+				store, root, line, flags, cancellable);
 			g_ptr_array_add (folders, fi);
 		}
 		g_free (path);
@@ -395,7 +450,8 @@ inode_hash (gconstpointer d)
 }
 
 static gboolean
-inode_equal (gconstpointer a, gconstpointer b)
+inode_equal (gconstpointer a,
+             gconstpointer b)
 {
 	const struct _inode *v1 = a, *v2 = b;
 
@@ -403,30 +459,13 @@ inode_equal (gconstpointer a, gconstpointer b)
 }
 
 static void
-inode_free (gpointer k, gpointer v, gpointer d)
+inode_free (gpointer k,
+            gpointer v,
+            gpointer d)
 {
 	g_free (k);
 }
 
-static void
-mh_store_constructed (GObject *object)
-{
-	CamelMhStore *mh_store;
-	CamelService *service;
-	CamelURL *url;
-
-	mh_store = CAMEL_MH_STORE (object);
-
-	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (camel_mh_store_parent_class)->constructed (object);
-
-	service = CAMEL_SERVICE (object);
-	url = camel_service_get_camel_url (service);
-
-	if (camel_url_get_param(url, "dotfolders"))
-		mh_store->flags |= CAMEL_MH_DOTFOLDERS;
-}
-
 static CamelFolder *
 mh_store_get_folder_sync (CamelStore *store,
                           const gchar *folder_name,
@@ -435,16 +474,28 @@ mh_store_get_folder_sync (CamelStore *store,
                           GError **error)
 {
 	CamelStoreClass *store_class;
+	CamelLocalStore *local_store;
+	CamelService *service;
+	CamelSettings *settings;
+	gboolean use_dot_folders;
 	gchar *name;
 	struct stat st;
 
+	local_store = CAMEL_LOCAL_STORE (store);
+
+	service = CAMEL_SERVICE (store);
+	settings = camel_service_get_settings (service);
+
+	use_dot_folders = camel_mh_settings_get_use_dot_folders (
+		CAMEL_MH_SETTINGS (settings));
+
 	/* Chain up to parent's get_folder() method. */
 	store_class = CAMEL_STORE_CLASS (camel_mh_store_parent_class);
 	if (store_class->get_folder_sync (
 		store, folder_name, flags, cancellable, error) == NULL)
 		return NULL;
 
-	name = g_strdup_printf("%s%s", CAMEL_LOCAL_STORE(store)->toplevel_dir, folder_name);
+	name = g_strconcat (local_store->toplevel_dir, folder_name, NULL);
 
 	if (g_stat (name, &st) == -1) {
 		if (errno != ENOENT) {
@@ -460,7 +511,8 @@ mh_store_get_folder_sync (CamelStore *store,
 			g_set_error (
 				error, CAMEL_STORE_ERROR,
 				CAMEL_STORE_ERROR_NO_FOLDER,
-				_("Cannot get folder '%s': folder does not exist."),
+				_("Cannot get folder '%s': "
+				  "folder does not exist."),
 				folder_name);
 			g_free (name);
 			return NULL;
@@ -478,8 +530,11 @@ mh_store_get_folder_sync (CamelStore *store,
 
 		/* add to .folders if we are supposed to */
 		/* FIXME: throw exception on error */
-		if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS)
-			folders_update (((CamelLocalStore *) store)->toplevel_dir, UPDATE_ADD, folder_name, NULL, cancellable);
+		if (use_dot_folders)
+			folders_update (
+				local_store->toplevel_dir,
+				UPDATE_ADD, folder_name, NULL, cancellable);
+
 	} else if (!S_ISDIR (st.st_mode)) {
 		g_set_error (
 			error, CAMEL_STORE_ERROR,
@@ -488,6 +543,7 @@ mh_store_get_folder_sync (CamelStore *store,
 			folder_name);
 		g_free (name);
 		return NULL;
+
 	} else if (flags & CAMEL_STORE_FOLDER_EXCL) {
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
@@ -499,7 +555,8 @@ mh_store_get_folder_sync (CamelStore *store,
 
 	g_free (name);
 
-	return camel_mh_folder_new (store, folder_name, flags, cancellable, error);
+	return camel_mh_folder_new (
+		store, folder_name, flags, cancellable, error);
 }
 
 static CamelFolderInfo *
@@ -509,17 +566,27 @@ mh_store_get_folder_info_sync (CamelStore *store,
                                GCancellable *cancellable,
                                GError **error)
 {
+	CamelService *service;
+	CamelSettings *settings;
 	CamelFolderInfo *fi = NULL;
 	CamelURL *url;
+	gboolean use_dot_folders;
 
-	url = camel_service_get_camel_url (CAMEL_SERVICE (store));
+	service = CAMEL_SERVICE (store);
+	url = camel_service_get_camel_url (service);
+	settings = camel_service_get_settings (service);
+
+	use_dot_folders = camel_mh_settings_get_use_dot_folders (
+		CAMEL_MH_SETTINGS (settings));
 
 	/* use .folders if we are supposed to */
-	if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS) {
+	if (use_dot_folders) {
 		folders_scan (
 			store, url->path, top, &fi, flags, cancellable);
 	} else {
-		GHashTable *visited = g_hash_table_new (inode_hash, inode_equal);
+		GHashTable *visited;
+
+		visited = g_hash_table_new (inode_hash, inode_equal);
 
 		if (top == NULL)
 			top = "";
@@ -528,7 +595,8 @@ mh_store_get_folder_info_sync (CamelStore *store,
 			store, &fi, NULL, visited, url->path,
 			top, flags, cancellable);
 
-		/* if we actually scanned from root, we have a "" root node we dont want */
+		/* If we actually scanned from root,
+		 * we have a "" root node we dont want. */
 		if (fi != NULL && top[0] == 0) {
 			CamelFolderInfo *rfi;
 
@@ -561,10 +629,22 @@ mh_store_delete_folder_sync (CamelStore *store,
                              GError **error)
 {
 	CamelStoreClass *store_class;
+	CamelLocalStore *local_store;
+	CamelService *service;
+	CamelSettings *settings;
+	gboolean use_dot_folders;
 	gchar *name;
 
+	local_store = CAMEL_LOCAL_STORE (store);
+
+	service = CAMEL_SERVICE (store);
+	settings = camel_service_get_settings (service);
+
+	use_dot_folders = camel_mh_settings_get_use_dot_folders (
+		CAMEL_MH_SETTINGS (settings));
+
 	/* remove folder directory - will fail if not empty */
-	name = g_strdup_printf("%s%s", CAMEL_LOCAL_STORE(store)->toplevel_dir, folder_name);
+	name = g_strconcat (local_store->toplevel_dir, folder_name, NULL);
 	if (rmdir (name) == -1) {
 		g_set_error (
 			error, G_IO_ERROR,
@@ -577,8 +657,10 @@ mh_store_delete_folder_sync (CamelStore *store,
 	g_free (name);
 
 	/* remove from .folders if we are supposed to */
-	if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS)
-		folders_update (((CamelLocalStore *) store)->toplevel_dir, UPDATE_REMOVE, folder_name, NULL, cancellable);
+	if (use_dot_folders)
+		folders_update (
+			local_store->toplevel_dir,
+			UPDATE_REMOVE, folder_name, NULL, cancellable);
 
 	/* Chain up to parent's delete_folder() method. */
 	store_class = CAMEL_STORE_CLASS (camel_mh_store_parent_class);
@@ -594,6 +676,18 @@ mh_store_rename_folder_sync (CamelStore *store,
                              GError **error)
 {
 	CamelStoreClass *store_class;
+	CamelLocalStore *local_store;
+	CamelService *service;
+	CamelSettings *settings;
+	gboolean use_dot_folders;
+
+	local_store = CAMEL_LOCAL_STORE (store);
+
+	service = CAMEL_SERVICE (store);
+	settings = camel_service_get_settings (service);
+
+	use_dot_folders = camel_mh_settings_get_use_dot_folders (
+		CAMEL_MH_SETTINGS (settings));
 
 	/* Chain up to parent's rename_folder() method. */
 	store_class = CAMEL_STORE_CLASS (camel_mh_store_parent_class);
@@ -601,9 +695,11 @@ mh_store_rename_folder_sync (CamelStore *store,
 		store, old, new, cancellable, error))
 		return FALSE;
 
-	if (((CamelMhStore *) store)->flags & CAMEL_MH_DOTFOLDERS) {
+	if (use_dot_folders) {
 		/* yeah this is messy, but so is mh! */
-		folders_update (((CamelLocalStore *) store)->toplevel_dir, UPDATE_RENAME, old, new, cancellable);
+		folders_update (
+			local_store->toplevel_dir,
+			UPDATE_RENAME, old, new, cancellable);
 	}
 
 	return TRUE;
@@ -612,11 +708,11 @@ mh_store_rename_folder_sync (CamelStore *store,
 static void
 camel_mh_store_class_init (CamelMhStoreClass *class)
 {
-	GObjectClass *object_class;
+	CamelServiceClass *service_class;
 	CamelStoreClass *store_class;
 
-	object_class = G_OBJECT_CLASS (class);
-	object_class->constructed = mh_store_constructed;
+	service_class = CAMEL_SERVICE_CLASS (class);
+	service_class->settings_type = CAMEL_TYPE_MH_SETTINGS;
 
 	store_class = CAMEL_STORE_CLASS (class);
 	store_class->get_folder_sync = mh_store_get_folder_sync;
